// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpdf_python.h"

// main header
#include "qpdfsearchmodel_wrapper.h"

// Wrappers providing overrides
#include "qpdfpagerenderer_wrapper.h"
#include "qpdfbookmarkmodel_wrapper.h"

// Argument includes
#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QStringList>
#include <QtPdf/qpdfdocument.h>
#include <QtPdf/qpdflink.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qmimedata.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qsize.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPdfSearchModelWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPdfSearchModelWrapper::QPdfSearchModelWrapper()
{
}

QPdfSearchModelWrapper::QPdfSearchModelWrapper(::QObject * parent) : QPdfSearchModel(parent)
{
}

::QModelIndex QPdfSearchModelWrapper::buddy(const ::QModelIndex & index) const
{
    static const char *funcName = "buddy";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::buddy(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_buddy("QPdfSearchModel", funcName, gil, pyOverride, index);
}

bool QPdfSearchModelWrapper::canDropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "canDropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::canDropMimeData(data, action, row, column, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_canDropMimeData("QPdfSearchModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool QPdfSearchModelWrapper::canFetchMore(const ::QModelIndex & parent) const
{
    static const char *funcName = "canFetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::canFetchMore(parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_canFetchMore("QPdfSearchModel", funcName, gil, pyOverride, parent);
}

void QPdfSearchModelWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QPdfPageRendererWrapper::sbk_o_childEvent("QPdfSearchModel", funcName, gil, pyOverride, event);
}

bool QPdfSearchModelWrapper::clearItemData(const ::QModelIndex & index)
{
    static const char *funcName = "clearItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::clearItemData(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_canFetchMore("QPdfSearchModel", funcName, gil, pyOverride, index);
}

void QPdfSearchModelWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QPdfPageRendererWrapper::sbk_o_connectNotify("QPdfSearchModel", funcName, gil, pyOverride, signal);
}

void QPdfSearchModelWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QPdfPageRendererWrapper::sbk_o_customEvent("QPdfSearchModel", funcName, gil, pyOverride, event);
}

::QVariant QPdfSearchModelWrapper::data(const ::QModelIndex & index, int role) const
{
    static const char *funcName = "data";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfSearchModel::data(index, role);
    }
    return QPdfBookmarkModelWrapper::sbk_o_data("QPdfSearchModel", funcName, gil, pyOverride, index, role);
}

void QPdfSearchModelWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QPdfPageRendererWrapper::sbk_o_connectNotify("QPdfSearchModel", funcName, gil, pyOverride, signal);
}

bool QPdfSearchModelWrapper::dropMimeData(const ::QMimeData * data, ::Qt::DropAction action, int row, int column, const ::QModelIndex & parent)
{
    static const char *funcName = "dropMimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractListModel::dropMimeData(data, action, row, column, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_canDropMimeData("QPdfSearchModel", funcName, gil, pyOverride, data, action, row, column, parent);
}

bool QPdfSearchModelWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QPdfPageRendererWrapper::sbk_o_event("QPdfSearchModel", funcName, gil, pyOverride, event);
}

bool QPdfSearchModelWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QPdfPageRendererWrapper::sbk_o_eventFilter("QPdfSearchModel", funcName, gil, pyOverride, watched, event);
}

void QPdfSearchModelWrapper::fetchMore(const ::QModelIndex & parent)
{
    static const char *funcName = "fetchMore";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::fetchMore(parent);
    }
    QPdfBookmarkModelWrapper::sbk_o_fetchMore("QPdfSearchModel", funcName, gil, pyOverride, parent);
}

::QFlags<Qt::ItemFlag> QPdfSearchModelWrapper::flags(const ::QModelIndex & index) const
{
    static const char *funcName = "flags";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractListModel::flags(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_flags("QPdfSearchModel", funcName, gil, pyOverride, index);
}

::QVariant QPdfSearchModelWrapper::headerData(int section, ::Qt::Orientation orientation, int role) const
{
    static const char *funcName = "headerData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::headerData(section, orientation, role);
    }
    return QPdfBookmarkModelWrapper::sbk_o_headerData("QPdfSearchModel", funcName, gil, pyOverride, section, orientation, role);
}

::QModelIndex QPdfSearchModelWrapper::index(int row, int column, const ::QModelIndex & parent) const
{
    static const char *funcName = "index";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractListModel::index(row, column, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_index("QPdfSearchModel", funcName, gil, pyOverride, row, column, parent);
}

bool QPdfSearchModelWrapper::insertColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::insertColumns(column, count, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_insertColumns("QPdfSearchModel", funcName, gil, pyOverride, column, count, parent);
}

bool QPdfSearchModelWrapper::insertRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "insertRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::insertRows(row, count, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_insertColumns("QPdfSearchModel", funcName, gil, pyOverride, row, count, parent);
}

::QMap<int,QVariant> QPdfSearchModelWrapper::itemData(const ::QModelIndex & index) const
{
    static const char *funcName = "itemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::itemData(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_itemData("QPdfSearchModel", funcName, gil, pyOverride, index);
}

::QList<QModelIndex> QPdfSearchModelWrapper::match(const ::QModelIndex & start, int role, const ::QVariant & value, int hits, ::QFlags<Qt::MatchFlag> flags) const
{
    static const char *funcName = "match";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::match(start, role, value, hits, flags);
    }
    return QPdfBookmarkModelWrapper::sbk_o_match("QPdfSearchModel", funcName, gil, pyOverride, start, role, value, hits, flags);
}

::QMimeData * QPdfSearchModelWrapper::mimeData(const ::QList<QModelIndex> & indexes) const
{
    static const char *funcName = "mimeData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::mimeData(indexes);
    }
    return QPdfBookmarkModelWrapper::sbk_o_mimeData("QPdfSearchModel", funcName, gil, pyOverride, indexes);
}

::QStringList QPdfSearchModelWrapper::mimeTypes() const
{
    static const char *funcName = "mimeTypes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::mimeTypes();
    }
    return QPdfBookmarkModelWrapper::sbk_o_mimeTypes("QPdfSearchModel", funcName, gil, pyOverride);
}

bool QPdfSearchModelWrapper::moveColumns(const ::QModelIndex & sourceParent, int sourceColumn, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveColumns(sourceParent, sourceColumn, count, destinationParent, destinationChild);
    }
    return QPdfBookmarkModelWrapper::sbk_o_moveColumns("QPdfSearchModel", funcName, gil, pyOverride, sourceParent, sourceColumn, count, destinationParent, destinationChild);
}

bool QPdfSearchModelWrapper::moveRows(const ::QModelIndex & sourceParent, int sourceRow, int count, const ::QModelIndex & destinationParent, int destinationChild)
{
    static const char *funcName = "moveRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::moveRows(sourceParent, sourceRow, count, destinationParent, destinationChild);
    }
    return QPdfBookmarkModelWrapper::sbk_o_moveColumns("QPdfSearchModel", funcName, gil, pyOverride, sourceParent, sourceRow, count, destinationParent, destinationChild);
}

void QPdfSearchModelWrapper::multiData(const ::QModelIndex & index, ::QModelRoleDataSpan roleDataSpan) const
{
    static const char *funcName = "multiData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::multiData(index, roleDataSpan);
    }
    QPdfBookmarkModelWrapper::sbk_o_multiData("QPdfSearchModel", funcName, gil, pyOverride, index, roleDataSpan);
}

bool QPdfSearchModelWrapper::removeColumns(int column, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeColumns";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::removeColumns(column, count, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_insertColumns("QPdfSearchModel", funcName, gil, pyOverride, column, count, parent);
}

bool QPdfSearchModelWrapper::removeRows(int row, int count, const ::QModelIndex & parent)
{
    static const char *funcName = "removeRows";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::removeRows(row, count, parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_insertColumns("QPdfSearchModel", funcName, gil, pyOverride, row, count, parent);
}

void QPdfSearchModelWrapper::resetInternalData()
{
    static const char *funcName = "resetInternalData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::resetInternalData();
    }
    QPdfBookmarkModelWrapper::sbk_o_resetInternalData("QPdfSearchModel", funcName, gil, pyOverride);
}

void QPdfSearchModelWrapper::revert()
{
    static const char *funcName = "revert";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::revert();
    }
    QPdfBookmarkModelWrapper::sbk_o_resetInternalData("QPdfSearchModel", funcName, gil, pyOverride);
}

::QHash<int,QByteArray> QPdfSearchModelWrapper::roleNames() const
{
    static const char *funcName = "roleNames";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfSearchModel::roleNames();
    }
    return QPdfBookmarkModelWrapper::sbk_o_roleNames("QPdfSearchModel", funcName, gil, pyOverride);
}

int QPdfSearchModelWrapper::rowCount(const ::QModelIndex & parent) const
{
    static const char *funcName = "rowCount";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfSearchModel::rowCount(parent);
    }
    return QPdfBookmarkModelWrapper::sbk_o_columnCount("QPdfSearchModel", funcName, gil, pyOverride, parent);
}

bool QPdfSearchModelWrapper::setData(const ::QModelIndex & index, const ::QVariant & value, int role)
{
    static const char *funcName = "setData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setData(index, value, role);
    }
    return QPdfBookmarkModelWrapper::sbk_o_setData("QPdfSearchModel", funcName, gil, pyOverride, index, value, role);
}

bool QPdfSearchModelWrapper::setHeaderData(int section, ::Qt::Orientation orientation, const ::QVariant & value, int role)
{
    static const char *funcName = "setHeaderData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setHeaderData(section, orientation, value, role);
    }
    return QPdfBookmarkModelWrapper::sbk_o_setHeaderData("QPdfSearchModel", funcName, gil, pyOverride, section, orientation, value, role);
}

bool QPdfSearchModelWrapper::setItemData(const ::QModelIndex & index, const ::QMap<int,QVariant> & roles)
{
    static const char *funcName = "setItemData";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::setItemData(index, roles);
    }
    return QPdfBookmarkModelWrapper::sbk_o_setItemData("QPdfSearchModel", funcName, gil, pyOverride, index, roles);
}

::QModelIndex QPdfSearchModelWrapper::sibling(int row, int column, const ::QModelIndex & idx) const
{
    static const char *funcName = "sibling";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractListModel::sibling(row, column, idx);
    }
    return QPdfBookmarkModelWrapper::sbk_o_index("QPdfSearchModel", funcName, gil, pyOverride, row, column, idx);
}

void QPdfSearchModelWrapper::sort(int column, ::Qt::SortOrder order)
{
    static const char *funcName = "sort";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::sort(column, order);
    }
    QPdfBookmarkModelWrapper::sbk_o_sort("QPdfSearchModel", funcName, gil, pyOverride, column, order);
}

::QSize QPdfSearchModelWrapper::span(const ::QModelIndex & index) const
{
    static const char *funcName = "span";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::span(index);
    }
    return QPdfBookmarkModelWrapper::sbk_o_span("QPdfSearchModel", funcName, gil, pyOverride, index);
}

bool QPdfSearchModelWrapper::submit()
{
    static const char *funcName = "submit";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::submit();
    }
    return QPdfBookmarkModelWrapper::sbk_o_submit("QPdfSearchModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QPdfSearchModelWrapper::supportedDragActions() const
{
    static const char *funcName = "supportedDragActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::supportedDragActions();
    }
    return QPdfBookmarkModelWrapper::sbk_o_supportedDragActions("QPdfSearchModel", funcName, gil, pyOverride);
}

::QFlags<Qt::DropAction> QPdfSearchModelWrapper::supportedDropActions() const
{
    static const char *funcName = "supportedDropActions";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QAbstractItemModel::supportedDropActions();
    }
    return QPdfBookmarkModelWrapper::sbk_o_supportedDragActions("QPdfSearchModel", funcName, gil, pyOverride);
}

void QPdfSearchModelWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QPdfSearchModel::timerEvent(event);
    }
    QPdfPageRendererWrapper::sbk_o_timerEvent("QPdfSearchModel", funcName, gil, pyOverride, event);
}

const QMetaObject *QPdfSearchModelWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPdfSearchModel::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPdfSearchModelWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPdfSearchModel::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPdfSearchModelWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPdfSearchModelWrapper *>(this));
    return QPdfSearchModel::qt_metacast(_clname);
}

QPdfSearchModelWrapper::~QPdfSearchModelWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPdfSearchModel_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPdfSearchModel >()))
        return -1;

    QPdfSearchModelWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPdfSearchModel", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPdfSearchModel::QPdfSearchModel()
    // 1: QPdfSearchModel::QPdfSearchModel(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QPdfSearchModel()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPdfSearchModel(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPdfSearchModel()
        {

            // QPdfSearchModel()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPdfSearchModelWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPdfSearchModelWrapper();
            }

            break;
        }
        case 1: // QPdfSearchModel(QObject *parent)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPdfSearchModel(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QPdfSearchModelWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QPdfSearchModelWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPdfSearchModel >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPdfSearchModelFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        int cppResult = const_cast<const ::QPdfSearchModel *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfSearchModelFunc_data(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "data", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractItemModel::data(QModelIndex,int)const->QVariant
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // data(QModelIndex,int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "data", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // data(QModelIndex,int)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPdfSearchModel *>(cppSelf)->::QPdfSearchModel::data(*cppArg0, cppArg1)
                : const_cast<const ::QPdfSearchModel *>(cppSelf)->data(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfSearchModelFunc_document(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // document()const
        QPdfDocument * cppResult = const_cast<const ::QPdfSearchModel *>(cppSelf)->document();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfSearchModelFunc_resultAtIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfSearchModel::resultAtIndex(int)const->QPdfLink
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // resultAtIndex(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resultAtIndex", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resultAtIndex(int)const
            QPdfLink cppResult = const_cast<const ::QPdfSearchModel *>(cppSelf)->resultAtIndex(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfLink_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfSearchModelFunc_resultsOnPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfSearchModel::resultsOnPage(int)const->QList<QPdfLink>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // resultsOnPage(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resultsOnPage", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resultsOnPage(int)const
            QList<QPdfLink> cppResult = const_cast<const ::QPdfSearchModel *>(cppSelf)->resultsOnPage(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPdfTypeConverters[SBK_QtPdf_QList_QPdfLink_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfSearchModelFunc_roleNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // roleNames()const
        QHash<int,QByteArray> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QPdfSearchModel *>(cppSelf)->::QPdfSearchModel::roleNames()
            : const_cast<const ::QPdfSearchModel *>(cppSelf)->roleNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtPdfTypeConverters[SBK_QtPdf_QHash_int_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfSearchModelFunc_rowCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractItemModel::rowCount(QModelIndex)const->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), (pyArg)))) {
        overloadId = 0; // rowCount(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rowCount", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QModelIndex cppArg0_local;
        ::QModelIndex *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // rowCount(QModelIndex)const
            int cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPdfSearchModel *>(cppSelf)->::QPdfSearchModel::rowCount(*cppArg0)
                : const_cast<const ::QPdfSearchModel *>(cppSelf)->rowCount(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfSearchModelFunc_searchString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // searchString()const
        QString cppResult = const_cast<const ::QPdfSearchModel *>(cppSelf)->searchString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfSearchModelFunc_setDocument(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfSearchModel::setDocument(QPdfDocument*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), (pyArg)))) {
        overloadId = 0; // setDocument(QPdfDocument*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocument", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPdfDocument *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocument(QPdfDocument*)
            cppSelf->setDocument(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfSearchModelFunc_setSearchString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfSearchModel::setSearchString(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setSearchString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSearchString", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSearchString(QString)
            cppSelf->setSearchString(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfSearchModelFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPdfSearchModel::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfSearchModelFunc_updatePage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfSearchModel::updatePage(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // updatePage(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "updatePage", errInfo, SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updatePage(int)
            cppSelf->updatePage(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QPdfSearchModel_PropertyStrings[] = {
    "count:",
    "document::",
    "searchString::",
    nullptr // Sentinel
};

static const char *Sbk_QPdfSearchModel_EnumFlagInfo[] = {
    "Role:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPdfSearchModel_methods[] = {
    {"count", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_count), METH_NOARGS, nullptr},
    {"data", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_data), METH_VARARGS, nullptr},
    {"document", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_document), METH_NOARGS, nullptr},
    {"resultAtIndex", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_resultAtIndex), METH_O, nullptr},
    {"resultsOnPage", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_resultsOnPage), METH_O, nullptr},
    {"roleNames", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_roleNames), METH_NOARGS, nullptr},
    {"rowCount", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_rowCount), METH_O, nullptr},
    {"searchString", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_searchString), METH_NOARGS, nullptr},
    {"setDocument", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_setDocument), METH_O, nullptr},
    {"setSearchString", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_setSearchString), METH_O, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_timerEvent), METH_O, nullptr},
    {"updatePage", reinterpret_cast<PyCFunction>(Sbk_QPdfSearchModelFunc_updatePage), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPdfSearchModel_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPdfSearchModel *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPdfSearchModelWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPdfSearchModel_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPdfSearchModel_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPdfSearchModel_Type = nullptr;
static PyTypeObject *Sbk_QPdfSearchModel_TypeF(void)
{
    return _Sbk_QPdfSearchModel_Type;
}

static PyType_Slot Sbk_QPdfSearchModel_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPdfSearchModel_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPdfSearchModel_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPdfSearchModel_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPdfSearchModel_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPdfSearchModel_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPdfSearchModel_spec = {
    "2:PySide6.QtPdf.QPdfSearchModel",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPdfSearchModel_slots
};

} //extern "C"

static void *Sbk_QPdfSearchModel_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPdfSearchModel *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPdfSearchModel_Role(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPdfSearchModel::Role>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPdfSearchModel::Role *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPdfSearchModel_Role_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_Role_IDX])))
        return Enum_PythonToCpp_QPdfSearchModel_Role;
    return {};
}

static PyObject *QPdfSearchModel_Role_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPdfSearchModel::Role>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPdfSearchModel::Role *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_Role_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPdfSearchModel_PythonToCpp_QPdfSearchModel_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPdfSearchModel_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPdfSearchModel_PythonToCpp_QPdfSearchModel_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfSearchModel_TypeF()))
        return QPdfSearchModel_PythonToCpp_QPdfSearchModel_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPdfSearchModel_PTR_CppToPython_QPdfSearchModel(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPdfSearchModel *>(const_cast<void *>(cppIn)), Sbk_QPdfSearchModel_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPdfSearchModel_SignatureStrings[] = {
    "1:PySide6.QtPdf.QPdfSearchModel(self,*:KeywordOnly=None,document:QPdfDocument=None,searchString:QString=None,count:int=None)",
    "0:PySide6.QtPdf.QPdfSearchModel(self,parent:PySide6.QtCore.QObject,*:KeywordOnly=None,document:QPdfDocument=None,searchString:QString=None,count:int=None)",
    "PySide6.QtPdf.QPdfSearchModel.count(self)->int",
    "PySide6.QtPdf.QPdfSearchModel.data(self,index:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex],role:int)->QVariant",
    "PySide6.QtPdf.QPdfSearchModel.document(self)->PySide6.QtPdf.QPdfDocument",
    "PySide6.QtPdf.QPdfSearchModel.resultAtIndex(self,index:int)->PySide6.QtPdf.QPdfLink",
    "PySide6.QtPdf.QPdfSearchModel.resultsOnPage(self,page:int)->QList[PySide6.QtPdf.QPdfLink]",
    "PySide6.QtPdf.QPdfSearchModel.roleNames(self)->QHash[int, PySide6.QtCore.QByteArray]",
    "PySide6.QtPdf.QPdfSearchModel.rowCount(self,parent:typing.Union[PySide6.QtCore.QModelIndex, PySide6.QtCore.QPersistentModelIndex])->int",
    "PySide6.QtPdf.QPdfSearchModel.searchString(self)->QString",
    "PySide6.QtPdf.QPdfSearchModel.setDocument(self,document:PySide6.QtPdf.QPdfDocument)",
    "PySide6.QtPdf.QPdfSearchModel.setSearchString(self,searchString:QString)",
    "PySide6.QtPdf.QPdfSearchModel.timerEvent(self,event:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtPdf.QPdfSearchModel.updatePage(self,page:int)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPdfSearchModel_SignatureByteSize = 344;
static constexpr uint8_t QPdfSearchModel_SignatureBytes[344] = {
    0x78, 0xda, 0xb5, 0x54, 0x4f, 0x4f, 0x83, 0x30, 0x1c, 0xbd, 0xef, 0x53, 0x78, 0x74, 0x06, 0x89,
    0x5e, 0x3c, 0x90, 0x68, 0x32, 0x37, 0x13, 0x8d, 0x73, 0x40, 0xd0, 0x5d, 0xc8, 0x0e, 0x95, 0xfe,
    0xc6, 0xaa, 0xd0, 0x92, 0xb6, 0x6c, 0xf2, 0xed, 0x2d, 0xff, 0x09, 0xa0, 0xe5, 0xa0, 0x17, 0x48,
    0xd3, 0xf7, 0x5e, 0xdf, 0xfb, 0xf1, 0xca, 0xb5, 0xe5, 0x64, 0x1e, 0xc1, 0x70, 0x63, 0xba, 0xd2,
    0xc1, 0x7b, 0xd3, 0x55, 0x0f, 0x0f, 0x10, 0x0f, 0x0e, 0x2f, 0x0c, 0x43, 0x74, 0x2e, 0x20, 0xda,
    0x1b, 0x17, 0xd6, 0x33, 0x64, 0x27, 0xc6, 0xb1, 0x4d, 0xa3, 0xec, 0x76, 0xc3, 0x28, 0x18, 0x98,
    0x05, 0x69, 0x0c, 0x54, 0x5a, 0x39, 0x61, 0x55, 0x2d, 0xca, 0x2d, 0x51, 0xd0, 0x3d, 0xc9, 0x09,
    0x0d, 0x2d, 0xb7, 0x7c, 0x97, 0x3b, 0x01, 0x4b, 0x15, 0x83, 0x54, 0xc0, 0xf9, 0xec, 0x6a, 0xca,
    0xe1, 0x09, 0xe2, 0xf9, 0x39, 0x2d, 0x72, 0xc9, 0x38, 0x98, 0xae, 0xfd, 0xfe, 0x01, 0x81, 0xfc,
    0x37, 0x6b, 0xbf, 0x1a, 0x33, 0x0b, 0x74, 0x61, 0x6f, 0x7e, 0x79, 0xa7, 0x48, 0x1a, 0x38, 0x46,
    0x12, 0x95, 0x61, 0x08, 0xc5, 0xf0, 0x65, 0xc9, 0x2c, 0x51, 0x07, 0x9b, 0x6f, 0x94, 0x30, 0xea,
    0xf7, 0x83, 0x15, 0x94, 0xa7, 0x1c, 0x67, 0x9c, 0xf5, 0xf7, 0x1c, 0xe0, 0x82, 0x08, 0xa9, 0xf2,
    0xb4, 0xa8, 0x9d, 0xc1, 0x59, 0x04, 0xb9, 0x75, 0xe5, 0xc5, 0xdd, 0x22, 0x4e, 0x90, 0xde, 0x50,
    0x35, 0x95, 0x3a, 0xc2, 0x10, 0x5d, 0xcf, 0x4d, 0x23, 0xc4, 0x41, 0xa4, 0x91, 0x5c, 0xc8, 0xc2,
    0x49, 0x37, 0x62, 0x69, 0x67, 0x48, 0x5e, 0x13, 0xfa, 0x39, 0x49, 0x53, 0xd8, 0xd4, 0x41, 0x21,
    0xd4, 0x1d, 0x08, 0x9b, 0x84, 0x6b, 0x35, 0x00, 0x7f, 0x5c, 0x78, 0xa7, 0x53, 0x56, 0x83, 0xda,
    0xa0, 0x18, 0x44, 0x9d, 0xdb, 0x7d, 0x44, 0xe2, 0xe0, 0x2b, 0xe1, 0xe1, 0xa8, 0xef, 0x33, 0x09,
    0x0b, 0xce, 0x51, 0xa6, 0x17, 0x3d, 0x2d, 0x9b, 0x3a, 0xd4, 0x6d, 0xfd, 0xdb, 0x2f, 0x3c, 0xa9,
    0x64, 0xdd, 0x6e, 0x37, 0xf9, 0xca, 0xa5, 0x96, 0x29, 0x57, 0xdd, 0x42, 0xb4, 0x37, 0xe8, 0xe7,
    0x5e, 0xcc, 0xf5, 0x9a, 0x5e, 0xdf, 0xd0, 0xe8, 0xf5, 0xd3, 0x09, 0x49, 0x12, 0x03, 0x7f, 0x38,
    0x36, 0xde, 0xe0, 0x38, 0xf6, 0x37, 0x78, 0x6d, 0x50, 0x3a, 0xbd, 0x34, 0x51, 0xb7, 0x11, 0x46,
    0xaa, 0x35, 0xfb, 0x06, 0x3b, 0x2e, 0xd0, 0xe1
};
#endif

PyTypeObject *init_QPdfSearchModel(PyObject *module)
{
    if (SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX].type != nullptr)
        return SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX].type;

    Shiboken::AutoDecRef Sbk_QPdfSearchModel_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractListModel_IDX]))));

    _Sbk_QPdfSearchModel_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPdfSearchModel",
        "QPdfSearchModel*",
        &Sbk_QPdfSearchModel_spec,
        &Shiboken::callCppDestructor< QPdfSearchModel >,
        Sbk_QPdfSearchModel_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPdfSearchModel_TypeF(); // references _Sbk_QPdfSearchModel_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPdfSearchModel_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPdfSearchModel_SignatureBytes, QPdfSearchModel_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPdfSearchModel_PropertyStrings);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPdfSearchModel_PythonToCpp_QPdfSearchModel_PTR,
        is_QPdfSearchModel_PythonToCpp_QPdfSearchModel_PTR_Convertible,
        QPdfSearchModel_PTR_CppToPython_QPdfSearchModel);

    Shiboken::Conversions::registerConverterName(converter, "QPdfSearchModel");
    Shiboken::Conversions::registerConverterName(converter, "QPdfSearchModel*");
    Shiboken::Conversions::registerConverterName(converter, "QPdfSearchModel&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPdfSearchModel).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPdfSearchModelWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPdfSearchModel_TypeF(), &Sbk_QPdfSearchModel_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPdfSearchModel_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Role'.
    const char *Role_Initializer[] = {
        "Page",
        "IndexOnPage",
        "Location",
        "ContextBefore",
        "ContextAfter",
        "NRoles",
        nullptr};
    // "int16_t" used instead of "int"
    constexpr int16_t Role_InitializerValues[] = {
        int16_t(QPdfSearchModel::Role::Page),          //  0x0100  256
        int16_t(QPdfSearchModel::Role::IndexOnPage),   //  0x0101  257
        int16_t(QPdfSearchModel::Role::Location),      //  0x0102  258
        int16_t(QPdfSearchModel::Role::ContextBefore), //  0x0103  259
        int16_t(QPdfSearchModel::Role::ContextAfter),  //  0x0104  260
        int16_t(QPdfSearchModel::Role::NRoles)         //  0x0105  261
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPdfSearchModel_TypeF(),
        "2:PySide6.QtPdf.QPdfSearchModel.Role",
        Role_Initializer, Role_InitializerValues);
    SbkPySide6_QtPdfTypeStructs[SBK_QPdfSearchModel_Role_IDX].type = EType;
    // Register converter for enum 'QPdfSearchModel::Role'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPdfSearchModel_Role_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPdfSearchModel_Role,
            is_Enum_PythonToCpp_QPdfSearchModel_Role_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPdfSearchModel::Role");
        Shiboken::Conversions::registerConverterAlias(converter, "Role");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Role' enum.

    PySide::Signal::registerSignals(pyType, &::QPdfSearchModel::staticMetaObject);
    qRegisterMetaType< ::QPdfSearchModel::Role >("QPdfSearchModel::Role");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPdfSearchModel::staticMetaObject, sizeof(QPdfSearchModelWrapper));

    return pyType;
}
