// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtpdfwidgets_python.h"

// main header
#include "qpdfpageselector_wrapper.h"

// Wrappers providing overrides
#include "qpdfview_wrapper.h"

// Argument includes
#include <QString>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPdfPageSelectorWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPdfPageSelectorWrapper::QPdfPageSelectorWrapper()
{
}

QPdfPageSelectorWrapper::QPdfPageSelectorWrapper(::QWidget * parent) : QPdfPageSelector(parent)
{
}

void QPdfPageSelectorWrapper::actionEvent(::QActionEvent * event)
{
    static const char *funcName = "actionEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::actionEvent(event);
    }
    QPdfViewWrapper::sbk_o_actionEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::changeEvent(::QEvent * event)
{
    static const char *funcName = "changeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::changeEvent(event);
    }
    QPdfViewWrapper::sbk_o_changeEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QPdfViewWrapper::sbk_o_childEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::closeEvent(::QCloseEvent * event)
{
    static const char *funcName = "closeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::closeEvent(event);
    }
    QPdfViewWrapper::sbk_o_closeEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QPdfViewWrapper::sbk_o_connectNotify("QPdfPageSelector", funcName, gil, pyOverride, signal);
}

void QPdfPageSelectorWrapper::contextMenuEvent(::QContextMenuEvent * event)
{
    static const char *funcName = "contextMenuEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::contextMenuEvent(event);
    }
    QPdfViewWrapper::sbk_o_contextMenuEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QPdfViewWrapper::sbk_o_customEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

int QPdfPageSelectorWrapper::devType() const
{
    static const char *funcName = "devType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::devType();
    }
    return QPdfViewWrapper::sbk_o_devType("QPdfPageSelector", funcName, gil, pyOverride);
}

void QPdfPageSelectorWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QPdfViewWrapper::sbk_o_connectNotify("QPdfPageSelector", funcName, gil, pyOverride, signal);
}

void QPdfPageSelectorWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    static const char *funcName = "dragEnterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragEnterEvent(event);
    }
    QPdfViewWrapper::sbk_o_dragEnterEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    static const char *funcName = "dragLeaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    QPdfViewWrapper::sbk_o_dragLeaveEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    static const char *funcName = "dragMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dragMoveEvent(event);
    }
    QPdfViewWrapper::sbk_o_dragMoveEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::dropEvent(::QDropEvent * event)
{
    static const char *funcName = "dropEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::dropEvent(event);
    }
    QPdfViewWrapper::sbk_o_dropEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::enterEvent(::QEnterEvent * event)
{
    static const char *funcName = "enterEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::enterEvent(event);
    }
    QPdfViewWrapper::sbk_o_enterEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

bool QPdfPageSelectorWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::event(event);
    }
    return QPdfViewWrapper::sbk_o_event("QPdfPageSelector", funcName, gil, pyOverride, event);
}

bool QPdfPageSelectorWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QPdfViewWrapper::sbk_o_eventFilter("QPdfPageSelector", funcName, gil, pyOverride, watched, event);
}

void QPdfPageSelectorWrapper::focusInEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusInEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusInEvent(event);
    }
    QPdfViewWrapper::sbk_o_focusInEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

bool QPdfPageSelectorWrapper::focusNextPrevChild(bool next)
{
    static const char *funcName = "focusNextPrevChild";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusNextPrevChild(next);
    }
    return QPdfViewWrapper::sbk_o_focusNextPrevChild("QPdfPageSelector", funcName, gil, pyOverride, next);
}

void QPdfPageSelectorWrapper::focusOutEvent(::QFocusEvent * event)
{
    static const char *funcName = "focusOutEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::focusOutEvent(event);
    }
    QPdfViewWrapper::sbk_o_focusOutEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

bool QPdfPageSelectorWrapper::hasHeightForWidth() const
{
    static const char *funcName = "hasHeightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hasHeightForWidth();
    }
    return QPdfViewWrapper::sbk_o_hasHeightForWidth("QPdfPageSelector", funcName, gil, pyOverride);
}

int QPdfPageSelectorWrapper::heightForWidth(int arg__1) const
{
    static const char *funcName = "heightForWidth";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::heightForWidth(arg__1);
    }
    return QPdfViewWrapper::sbk_o_heightForWidth("QPdfPageSelector", funcName, gil, pyOverride, arg__1);
}

void QPdfPageSelectorWrapper::hideEvent(::QHideEvent * event)
{
    static const char *funcName = "hideEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::hideEvent(event);
    }
    QPdfViewWrapper::sbk_o_hideEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::initPainter(::QPainter * painter) const
{
    static const char *funcName = "initPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::initPainter(painter);
    }
    QPdfViewWrapper::sbk_o_initPainter("QPdfPageSelector", funcName, gil, pyOverride, painter);
}

void QPdfPageSelectorWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    static const char *funcName = "inputMethodEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodEvent(event);
    }
    QPdfViewWrapper::sbk_o_inputMethodEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

::QVariant QPdfPageSelectorWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    static const char *funcName = "inputMethodQuery";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::inputMethodQuery(arg__1);
    }
    return QPdfViewWrapper::sbk_o_inputMethodQuery("QPdfPageSelector", funcName, gil, pyOverride, arg__1);
}

void QPdfPageSelectorWrapper::keyPressEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyPressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyPressEvent(event);
    }
    QPdfViewWrapper::sbk_o_keyPressEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    static const char *funcName = "keyReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    QPdfViewWrapper::sbk_o_keyReleaseEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::leaveEvent(::QEvent * event)
{
    static const char *funcName = "leaveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[27], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::leaveEvent(event);
    }
    QPdfViewWrapper::sbk_o_leaveEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

int QPdfPageSelectorWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    static const char *funcName = "metric";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[28], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::metric(arg__1);
    }
    return QPdfViewWrapper::sbk_o_metric("QPdfPageSelector", funcName, gil, pyOverride, arg__1);
}

::QSize QPdfPageSelectorWrapper::minimumSizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:minimumSizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[29], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::minimumSizeHint();
    }
    return QPdfViewWrapper::sbk_o_minimumSizeHint("QPdfPageSelector", funcName, gil, pyOverride);
}

void QPdfPageSelectorWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseDoubleClickEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[30], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    QPdfViewWrapper::sbk_o_mouseDoubleClickEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseMoveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[31], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    QPdfViewWrapper::sbk_o_mouseMoveEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::mousePressEvent(::QMouseEvent * event)
{
    static const char *funcName = "mousePressEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[32], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mousePressEvent(event);
    }
    QPdfViewWrapper::sbk_o_mousePressEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    static const char *funcName = "mouseReleaseEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[33], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    QPdfViewWrapper::sbk_o_mouseReleaseEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::moveEvent(::QMoveEvent * event)
{
    static const char *funcName = "moveEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[34], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::moveEvent(event);
    }
    QPdfViewWrapper::sbk_o_moveEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

bool QPdfPageSelectorWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    static const char *funcName = "nativeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[35], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    return QPdfViewWrapper::sbk_o_nativeEvent("QPdfPageSelector", funcName, gil, pyOverride, eventType, message, result);
}

::QPaintEngine * QPdfPageSelectorWrapper::paintEngine() const
{
    static const char *funcName = "paintEngine";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[36], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEngine();
    }
    return QPdfViewWrapper::sbk_o_paintEngine("QPdfPageSelector", funcName, gil, pyOverride);
}

void QPdfPageSelectorWrapper::paintEvent(::QPaintEvent * event)
{
    static const char *funcName = "paintEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[37], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::paintEvent(event);
    }
    QPdfViewWrapper::sbk_o_paintEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

::QPaintDevice * QPdfPageSelectorWrapper::redirected(::QPoint * offset) const
{
    static const char *funcName = "redirected";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[38], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::redirected(offset);
    }
    return QPdfViewWrapper::sbk_o_redirected("QPdfPageSelector", funcName, gil, pyOverride, offset);
}

void QPdfPageSelectorWrapper::resizeEvent(::QResizeEvent * event)
{
    static const char *funcName = "resizeEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[39], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::resizeEvent(event);
    }
    QPdfViewWrapper::sbk_o_resizeEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::setVisible(bool visible)
{
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[40], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::setVisible(visible);
    }
    QPdfViewWrapper::sbk_o_setVisible("QPdfPageSelector", funcName, gil, pyOverride, visible);
}

::QPainter * QPdfPageSelectorWrapper::sharedPainter() const
{
    static const char *funcName = "sharedPainter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[41], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sharedPainter();
    }
    return QPdfViewWrapper::sbk_o_sharedPainter("QPdfPageSelector", funcName, gil, pyOverride);
}

void QPdfPageSelectorWrapper::showEvent(::QShowEvent * event)
{
    static const char *funcName = "showEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[42], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::showEvent(event);
    }
    QPdfViewWrapper::sbk_o_showEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

::QSize QPdfPageSelectorWrapper::sizeHint() const
{
    // This method belongs to a property.
    static const char *funcName = "1:sizeHint";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[43], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::sizeHint();
    }
    return QPdfViewWrapper::sbk_o_minimumSizeHint("QPdfPageSelector", funcName, gil, pyOverride);
}

void QPdfPageSelectorWrapper::tabletEvent(::QTabletEvent * event)
{
    static const char *funcName = "tabletEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[44], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::tabletEvent(event);
    }
    QPdfViewWrapper::sbk_o_tabletEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[45], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QPdfViewWrapper::sbk_o_timerEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

void QPdfPageSelectorWrapper::wheelEvent(::QWheelEvent * event)
{
    static const char *funcName = "wheelEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[46], nameCache));
    if (pyOverride.isNull()) {
        return this->::QWidget::wheelEvent(event);
    }
    QPdfViewWrapper::sbk_o_wheelEvent("QPdfPageSelector", funcName, gil, pyOverride, event);
}

const QMetaObject *QPdfPageSelectorWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPdfPageSelector::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPdfPageSelectorWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPdfPageSelector::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPdfPageSelectorWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPdfPageSelectorWrapper *>(this));
    return QPdfPageSelector::qt_metacast(_clname);
}

QPdfPageSelectorWrapper::~QPdfPageSelectorWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPdfPageSelector_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPdfPageSelector >()))
        return -1;

    QPdfPageSelectorWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPdfPageSelector", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPdfPageSelector::QPdfPageSelector()
    // 1: QPdfPageSelector::QPdfPageSelector(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QPdfPageSelector()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QPdfPageSelector(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPdfPageSelector()
        {

            // QPdfPageSelector()
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QPdfPageSelectorWrapper();
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QPdfPageSelectorWrapper();
            }

            break;
        }
        case 1: // QPdfPageSelector(QWidget *parent)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPdfPageSelector(QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QPdfPageSelectorWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QPdfPageSelectorWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPdfPageSelector >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPdfPageSelectorFunc_currentPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfPageSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentPage()const
        int cppResult = const_cast<const ::QPdfPageSelector *>(cppSelf)->currentPage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfPageSelectorFunc_currentPageLabel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfPageSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentPageLabel()const
        QString cppResult = const_cast<const ::QPdfPageSelector *>(cppSelf)->currentPageLabel();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfPageSelectorFunc_document(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfPageSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // document()const
        QPdfDocument * cppResult = const_cast<const ::QPdfPageSelector *>(cppSelf)->document();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QPdfPageSelectorFunc_setCurrentPage(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfPageSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfPageSelector::setCurrentPage(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCurrentPage(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentPage", errInfo, SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentPage(int)
            cppSelf->setCurrentPage(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QPdfPageSelectorFunc_setDocument(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPdfPageSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPdfPageSelector::setDocument(QPdfDocument*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtPdfTypeStructs[SBK_QPdfDocument_IDX]), (pyArg)))) {
        overloadId = 0; // setDocument(QPdfDocument*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocument", errInfo, SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPdfDocument *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocument(QPdfDocument*)
            cppSelf->setDocument(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QPdfPageSelector_PropertyStrings[] = {
    "currentPage::",
    "currentPageLabel:",
    "document::",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPdfPageSelector_methods[] = {
    {"currentPage", reinterpret_cast<PyCFunction>(Sbk_QPdfPageSelectorFunc_currentPage), METH_NOARGS, nullptr},
    {"currentPageLabel", reinterpret_cast<PyCFunction>(Sbk_QPdfPageSelectorFunc_currentPageLabel), METH_NOARGS, nullptr},
    {"document", reinterpret_cast<PyCFunction>(Sbk_QPdfPageSelectorFunc_document), METH_NOARGS, nullptr},
    {"setCurrentPage", reinterpret_cast<PyCFunction>(Sbk_QPdfPageSelectorFunc_setCurrentPage), METH_O, nullptr},
    {"setDocument", reinterpret_cast<PyCFunction>(Sbk_QPdfPageSelectorFunc_setDocument), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPdfPageSelector_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPdfPageSelector *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPdfPageSelectorWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPdfPageSelector_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPdfPageSelector_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QPdfPageSelectorSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QPdfPageSelector *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPdfPageSelector_Type = nullptr;
static PyTypeObject *Sbk_QPdfPageSelector_TypeF(void)
{
    return _Sbk_QPdfPageSelector_Type;
}

static PyType_Slot Sbk_QPdfPageSelector_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPdfPageSelector_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPdfPageSelector_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPdfPageSelector_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPdfPageSelector_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPdfPageSelector_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPdfPageSelector_spec = {
    "2:PySide6.QtPdfWidgets.QPdfPageSelector",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPdfPageSelector_slots
};

} //extern "C"

static void *Sbk_QPdfPageSelector_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QPdfPageSelector *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPdfPageSelector *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QPdfPageSelector *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPdfPageSelector_PythonToCpp_QPdfPageSelector_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPdfPageSelector_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPdfPageSelector_PythonToCpp_QPdfPageSelector_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPdfPageSelector_TypeF()))
        return QPdfPageSelector_PythonToCpp_QPdfPageSelector_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPdfPageSelector_PTR_CppToPython_QPdfPageSelector(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPdfPageSelector *>(const_cast<void *>(cppIn)), Sbk_QPdfPageSelector_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPdfPageSelector_SignatureStrings[] = {
    "1:PySide6.QtPdfWidgets.QPdfPageSelector(self,*:KeywordOnly=None,document:QPdfDocument=None,currentPage:int=None,currentPageLabel:QString=None)",
    "0:PySide6.QtPdfWidgets.QPdfPageSelector(self,parent:PySide6.QtWidgets.QWidget,*:KeywordOnly=None,document:QPdfDocument=None,currentPage:int=None,currentPageLabel:QString=None)",
    "PySide6.QtPdfWidgets.QPdfPageSelector.currentPage(self)->int",
    "PySide6.QtPdfWidgets.QPdfPageSelector.currentPageLabel(self)->QString",
    "PySide6.QtPdfWidgets.QPdfPageSelector.document(self)->PySide6.QtPdf.QPdfDocument",
    "PySide6.QtPdfWidgets.QPdfPageSelector.setCurrentPage(self,index:int)",
    "PySide6.QtPdfWidgets.QPdfPageSelector.setDocument(self,document:PySide6.QtPdf.QPdfDocument)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPdfPageSelector_SignatureByteSize = 195;
static constexpr uint8_t QPdfPageSelector_SignatureBytes[195] = {
    0x78, 0xda, 0xbd, 0x91, 0xbd, 0x0e, 0xc2, 0x20, 0x14, 0x46, 0xf7, 0x3e, 0x89, 0x98, 0x4a, 0x74,
    0x71, 0x20, 0xd1, 0xc5, 0x6e, 0x1a, 0x6d, 0xd3, 0xc1, 0x19, 0xcb, 0x6d, 0x43, 0x42, 0xc1, 0x50,
    0x1a, 0xed, 0xdb, 0x5b, 0xfa, 0xa3, 0x68, 0x34, 0xa1, 0x8b, 0x1b, 0x97, 0xcb, 0x77, 0x38, 0x5c,
    0x56, 0x24, 0x6e, 0x52, 0xce, 0x60, 0x8d, 0x13, 0x13, 0xb3, 0xfc, 0xcc, 0x59, 0x01, 0xa6, 0xc2,
    0x49, 0xbb, 0x8e, 0x69, 0x01, 0x29, 0x08, 0xc8, 0x8c, 0xd2, 0xb3, 0x0a, 0x44, 0x1e, 0xce, 0xc9,
    0x1e, 0x9a, 0x9b, 0xd2, 0xec, 0x24, 0x45, 0xb3, 0x39, 0x2a, 0x09, 0x21, 0x53, 0x59, 0x5d, 0x82,
    0x34, 0xc4, 0x26, 0xa2, 0xa1, 0xe8, 0x5b, 0x59, 0xad, 0x75, 0x5b, 0x58, 0x0c, 0xe1, 0x5f, 0x36,
    0x0f, 0xf4, 0x02, 0x82, 0x24, 0xa9, 0xd1, 0x5c, 0x16, 0x5d, 0x17, 0x05, 0xcb, 0x29, 0x3a, 0x57,
    0x6a, 0x51, 0x4e, 0xe2, 0x79, 0xbc, 0x5f, 0xfc, 0xc1, 0xd7, 0xcb, 0x16, 0x3b, 0x90, 0xce, 0x1c,
    0x2d, 0xb6, 0xed, 0x05, 0xd3, 0xc3, 0x9d, 0xc1, 0x48, 0x18, 0x44, 0x3c, 0x29, 0xe3, 0xbb, 0xc7,
    0xf4, 0x5b, 0x0a, 0xbb, 0xc3, 0xf0, 0x04, 0x56, 0x60, 0x76, 0x1f, 0xcf, 0x0a, 0xb9, 0x64, 0x70,
    0xb7, 0xb3, 0x43, 0xfe, 0x90, 0xc8, 0x15, 0x7b, 0x7d, 0xcf, 0x6f, 0x3f, 0x14, 0x3c, 0x00, 0xaa,
    0xfd, 0xfd, 0x55
};
#endif

PyTypeObject *init_QPdfPageSelector(PyObject *module)
{
    if (SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX].type != nullptr)
        return SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX].type;

    Shiboken::AutoDecRef Sbk_QPdfPageSelector_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))));

    _Sbk_QPdfPageSelector_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPdfPageSelector",
        "QPdfPageSelector*",
        &Sbk_QPdfPageSelector_spec,
        &Shiboken::callCppDestructor< QPdfPageSelector >,
        Sbk_QPdfPageSelector_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QPdfPageSelector_TypeF(); // references _Sbk_QPdfPageSelector_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPdfPageSelector_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPdfPageSelector_SignatureBytes, QPdfPageSelector_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPdfPageSelector_PropertyStrings);
    SbkPySide6_QtPdfWidgetsTypeStructs[SBK_QPdfPageSelector_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPdfPageSelector_PythonToCpp_QPdfPageSelector_PTR,
        is_QPdfPageSelector_PythonToCpp_QPdfPageSelector_PTR_Convertible,
        QPdfPageSelector_PTR_CppToPython_QPdfPageSelector);

    Shiboken::Conversions::registerConverterName(converter, "QPdfPageSelector");
    Shiboken::Conversions::registerConverterName(converter, "QPdfPageSelector*");
    Shiboken::Conversions::registerConverterName(converter, "QPdfPageSelector&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPdfPageSelector).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPdfPageSelectorWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QPdfPageSelector_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QPdfPageSelector_TypeF(), &Sbk_QPdfPageSelectorSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPdfPageSelector_TypeF(), &Sbk_QPdfPageSelector_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::QPdfPageSelector::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPdfPageSelector::staticMetaObject, sizeof(QPdfPageSelectorWrapper));

    return pyType;
}
