// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef SBK_QWEBENGINEPAGEWRAPPER_H
#define SBK_QWEBENGINEPAGEWRAPPER_H

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

#include <QtWebEngineCore/qwebenginepage.h>

namespace Shiboken { class AutoDecRef; class GilState; }

namespace PySide { class DynamicQMetaObject; }

class QWebEnginePageWrapper : public QWebEnginePage
{
public:
    QWebEnginePageWrapper(::QObject * parent = nullptr);
    QWebEnginePageWrapper(::QWebEngineProfile * profile, ::QObject * parent = nullptr);
    QWebEnginePageWrapper(const QWebEnginePageWrapper &) = delete;
    QWebEnginePageWrapper& operator=(const QWebEnginePageWrapper &) = delete;
    QWebEnginePageWrapper(QWebEnginePageWrapper &&) = delete;
    QWebEnginePageWrapper& operator=(QWebEnginePageWrapper &&) = delete;
    ~QWebEnginePageWrapper() override;

    bool acceptNavigationRequest(const ::QUrl & url, ::QWebEnginePage::NavigationType type, bool isMainFrame) override;
    static bool sbk_o_acceptNavigationRequest(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & url, ::QWebEnginePage::NavigationType type, bool isMainFrame);
    void childEvent(::QChildEvent * event) override;
    ::QStringList chooseFiles(::QWebEnginePage::FileSelectionMode mode, const ::QStringList & oldFiles, const ::QStringList & acceptedMimeTypes) override;
    static ::QStringList sbk_o_chooseFiles(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWebEnginePage::FileSelectionMode mode, const ::QStringList & oldFiles, const ::QStringList & acceptedMimeTypes);
    void connectNotify(const ::QMetaMethod & signal) override;
    ::QWebEnginePage * createWindow(::QWebEnginePage::WebWindowType type) override;
    static ::QWebEnginePage * sbk_o_createWindow(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWebEnginePage::WebWindowType type);
    void customEvent(::QEvent * event) override;
    void disconnectNotify(const ::QMetaMethod & signal) override;
    bool event(::QEvent * arg__1) override;
    bool eventFilter(::QObject * watched, ::QEvent * event) override;
    void javaScriptAlert(const ::QUrl & securityOrigin, const ::QString & msg) override;
    static void sbk_o_javaScriptAlert(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & securityOrigin, const ::QString & msg);
    bool javaScriptConfirm(const ::QUrl & securityOrigin, const ::QString & msg) override;
    static bool sbk_o_javaScriptConfirm(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & securityOrigin, const ::QString & msg);
    void javaScriptConsoleMessage(::QWebEnginePage::JavaScriptConsoleMessageLevel level, const ::QString & message, int lineNumber, const ::QString & sourceID) override;
    static void sbk_o_javaScriptConsoleMessage(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWebEnginePage::JavaScriptConsoleMessageLevel level, const ::QString & message, int lineNumber, const ::QString & sourceID);
    bool javaScriptPrompt(const ::QUrl & securityOrigin, const ::QString & msg, const ::QString & defaultValue, ::QString * result) override;
    static bool sbk_o_javaScriptPrompt(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, const ::QUrl & securityOrigin, const ::QString & msg, const ::QString & defaultValue, ::QString * result);
    void timerEvent(::QTimerEvent * event) override;
    void triggerAction(::QWebEnginePage::WebAction action, bool checked = false) override;
    static void sbk_o_triggerAction(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWebEnginePage::WebAction action, bool checked = false);

    const ::QMetaObject * metaObject() const override;
    int qt_metacall(QMetaObject::Call call, int id, void **args) override;
    void *qt_metacast(const char *_clname) override;
    static void pysideInitQtMetaTypes();

    void resetPyMethodCache();

private:
    static ::std::pair<bool,QString> javaScriptPromptPyOverride(Shiboken::GilState &gil, PyObject *pyOverride, ::QUrl securityOrigin, ::QString msg, ::QString defaultValue);

    mutable bool m_PyMethodCache[15] = {false, false, false, false, false, false, false, false, false, false, false, false, false, false, false};
};

#endif // SBK_QWEBENGINEPAGEWRAPPER_H
