// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineprofilebuilder_wrapper.h"

// Argument includes
#include <QString>
#include <QtWebEngineCore/qwebengineprofile.h>
#include <QtWebEngineCore/qwebengineprofilebuilder.h>
#include <qobject.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineProfileBuilder_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineProfileBuilder >()))
        return -1;

    ::QWebEngineProfileBuilder *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QWebEngineProfileBuilder()
        cptr = new ::QWebEngineProfileBuilder();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineProfileBuilder >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineProfileBuilderFunc_createOffTheRecordProfile(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createOffTheRecordProfile", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    if (PyArg_ParseTuple(args, "|O:createOffTheRecordProfile", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QWebEngineProfileBuilder::createOffTheRecordProfile(QObject*=)->QWebEngineProfile*
    if (numArgs == 0) {
        overloadId = 0; // createOffTheRecordProfile(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // createOffTheRecordProfile(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createOffTheRecordProfile", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "createOffTheRecordProfile", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createOffTheRecordProfile(QObject*)
            QWebEngineProfile * cppResult = ::QWebEngineProfileBuilder::createOffTheRecordProfile(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineProfileBuilderFunc_createProfile(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfileBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createProfile", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    if (PyArg_ParseTuple(args, "|OO:createProfile", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWebEngineProfileBuilder::createProfile(QString,QObject*=)const->QWebEngineProfile*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createProfile(QString,QObject*)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 0; // createProfile(QString,QObject*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createProfile", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "createProfile", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QObject *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createProfile(QString,QObject*)const
            QWebEngineProfile * cppResult = const_cast<const ::QWebEngineProfileBuilder *>(cppSelf)->createProfile(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineProfileBuilderFunc_setCachePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfileBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfileBuilder::setCachePath(QString)->QWebEngineProfileBuilder&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setCachePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCachePath", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCachePath(QString)
            QWebEngineProfileBuilder & cppResult = cppSelf->setCachePath(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineProfileBuilderFunc_setHttpCacheMaximumSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfileBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfileBuilder::setHttpCacheMaximumSize(int)->QWebEngineProfileBuilder&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setHttpCacheMaximumSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpCacheMaximumSize", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpCacheMaximumSize(int)
            QWebEngineProfileBuilder & cppResult = cppSelf->setHttpCacheMaximumSize(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineProfileBuilderFunc_setHttpCacheType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfileBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfileBuilder::setHttpCacheType(QWebEngineProfile::HttpCacheType)->QWebEngineProfileBuilder&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_HttpCacheType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHttpCacheType(QWebEngineProfile::HttpCacheType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHttpCacheType", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    // Call function/method
    {
        ::QWebEngineProfile::HttpCacheType cppArg0{QWebEngineProfile::MemoryHttpCache};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHttpCacheType(QWebEngineProfile::HttpCacheType)
            QWebEngineProfileBuilder & cppResult = cppSelf->setHttpCacheType(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineProfileBuilderFunc_setPersistentCookiesPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfileBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfileBuilder::setPersistentCookiesPolicy(QWebEngineProfile::PersistentCookiesPolicy)->QWebEngineProfileBuilder&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentCookiesPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPersistentCookiesPolicy(QWebEngineProfile::PersistentCookiesPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentCookiesPolicy", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    // Call function/method
    {
        ::QWebEngineProfile::PersistentCookiesPolicy cppArg0{QWebEngineProfile::NoPersistentCookies};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentCookiesPolicy(QWebEngineProfile::PersistentCookiesPolicy)
            QWebEngineProfileBuilder & cppResult = cppSelf->setPersistentCookiesPolicy(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineProfileBuilderFunc_setPersistentPermissionsPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfileBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfileBuilder::setPersistentPermissionsPolicy(QWebEngineProfile::PersistentPermissionsPolicy)->QWebEngineProfileBuilder&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfile_PersistentPermissionsPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPersistentPermissionsPolicy(QWebEngineProfile::PersistentPermissionsPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentPermissionsPolicy", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    // Call function/method
    {
        ::QWebEngineProfile::PersistentPermissionsPolicy cppArg0{QWebEngineProfile::PersistentPermissionsPolicy::AskEveryTime};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentPermissionsPolicy(QWebEngineProfile::PersistentPermissionsPolicy)
            QWebEngineProfileBuilder & cppResult = cppSelf->setPersistentPermissionsPolicy(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineProfileBuilderFunc_setPersistentStoragePath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineProfileBuilder *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineProfileBuilder::setPersistentStoragePath(QString)->QWebEngineProfileBuilder&
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPersistentStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPersistentStoragePath", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPersistentStoragePath(QString)
            QWebEngineProfileBuilder & cppResult = cppSelf->setPersistentStoragePath(cppArg0);
            pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_QWebEngineProfileBuilder_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineProfileBuilder_methods[] = {
    {"createOffTheRecordProfile", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileBuilderFunc_createOffTheRecordProfile), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"createProfile", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileBuilderFunc_createProfile), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCachePath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileBuilderFunc_setCachePath), METH_O, nullptr},
    {"setHttpCacheMaximumSize", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileBuilderFunc_setHttpCacheMaximumSize), METH_O, nullptr},
    {"setHttpCacheType", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileBuilderFunc_setHttpCacheType), METH_O, nullptr},
    {"setPersistentCookiesPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileBuilderFunc_setPersistentCookiesPolicy), METH_O, nullptr},
    {"setPersistentPermissionsPolicy", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileBuilderFunc_setPersistentPermissionsPolicy), METH_O, nullptr},
    {"setPersistentStoragePath", reinterpret_cast<PyCFunction>(Sbk_QWebEngineProfileBuilderFunc_setPersistentStoragePath), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineProfileBuilder_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineProfileBuilder_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineProfileBuilder_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineProfileBuilder_TypeF(void)
{
    return _Sbk_QWebEngineProfileBuilder_Type;
}

static PyType_Slot Sbk_QWebEngineProfileBuilder_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineProfileBuilder_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineProfileBuilder_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineProfileBuilder_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineProfileBuilder_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineProfileBuilder_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineProfileBuilder",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineProfileBuilder_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineProfileBuilder_PythonToCpp_QWebEngineProfileBuilder_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineProfileBuilder_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineProfileBuilder_PythonToCpp_QWebEngineProfileBuilder_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineProfileBuilder_TypeF()))
        return QWebEngineProfileBuilder_PythonToCpp_QWebEngineProfileBuilder_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineProfileBuilder_PTR_CppToPython_QWebEngineProfileBuilder(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineProfileBuilder_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineProfileBuilder_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder(self)",
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder.createOffTheRecordProfile(parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtWebEngineCore.QWebEngineProfile",
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder.createProfile(self,storageName:QString,parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtWebEngineCore.QWebEngineProfile",
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder.setCachePath(self,path:QString)->PySide6.QtWebEngineCore.QWebEngineProfileBuilder",
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder.setHttpCacheMaximumSize(self,maxSizeInBytes:int)->PySide6.QtWebEngineCore.QWebEngineProfileBuilder",
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder.setHttpCacheType(self,httpCacheType:PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType)->PySide6.QtWebEngineCore.QWebEngineProfileBuilder",
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder.setPersistentCookiesPolicy(self,persistentCookiesPolicy:PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy)->PySide6.QtWebEngineCore.QWebEngineProfileBuilder",
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder.setPersistentPermissionsPolicy(self,persistentPermissionPolicy:PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy)->PySide6.QtWebEngineCore.QWebEngineProfileBuilder",
    "PySide6.QtWebEngineCore.QWebEngineProfileBuilder.setPersistentStoragePath(self,path:QString)->PySide6.QtWebEngineCore.QWebEngineProfileBuilder",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineProfileBuilder_SignatureByteSize = 266;
static constexpr uint8_t QWebEngineProfileBuilder_SignatureBytes[266] = {
    0x78, 0xda, 0xcd, 0x94, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0xfc, 0x92, 0x4d, 0x1a, 0x3d,
    0x72, 0xa8, 0x34, 0x0e, 0xab, 0x90, 0xe0, 0xc0, 0x96, 0xd2, 0x49, 0x9c, 0xb3, 0xd6, 0x6d, 0x0d,
    0xf9, 0x92, 0xe3, 0x4a, 0x2b, 0xbf, 0x9e, 0x8e, 0x66, 0x0c, 0x04, 0x93, 0xd6, 0x0d, 0x55, 0xdc,
    0xec, 0xc4, 0x79, 0xfd, 0xbc, 0xf9, 0x12, 0x6d, 0x86, 0x05, 0xdc, 0x44, 0x29, 0x3f, 0xc3, 0xe6,
    0xce, 0x54, 0x68, 0x20, 0xb1, 0x04, 0x51, 0xfa, 0x99, 0x0a, 0xb2, 0x25, 0x2a, 0x58, 0x34, 0xa8,
    0x0a, 0xa0, 0x89, 0x07, 0x55, 0x4e, 0xaf, 0xc4, 0xc0, 0x65, 0x51, 0x4e, 0x20, 0x19, 0x56, 0x65,
    0xb9, 0xae, 0xe1, 0x09, 0x72, 0x4b, 0x45, 0x28, 0x98, 0x38, 0x49, 0x60, 0x38, 0x3e, 0x28, 0xf6,
    0x42, 0xab, 0xcd, 0x0b, 0xe4, 0x3c, 0x37, 0x8d, 0x52, 0x8e, 0x69, 0x7a, 0x7d, 0x7b, 0x72, 0xcb,
    0x73, 0xe1, 0xf6, 0x40, 0x3b, 0x87, 0x33, 0xcf, 0x96, 0x64, 0x05, 0x4b, 0xa9, 0x21, 0x4e, 0x33,
    0x26, 0x34, 0xd5, 0xec, 0x1f, 0x90, 0x7a, 0xe0, 0x44, 0xe6, 0x35, 0x08, 0xc9, 0x75, 0x0f, 0xea,
    0xba, 0x68, 0x4f, 0x38, 0xa4, 0x77, 0x50, 0x3c, 0x0b, 0xe1, 0x9e, 0xd9, 0x7d, 0x60, 0x3c, 0xca,
    0x2d, 0xea, 0x46, 0x67, 0xf8, 0x16, 0xb6, 0x4d, 0xcb, 0xed, 0x2e, 0x79, 0x30, 0x8b, 0x96, 0xc1,
    0xc7, 0x68, 0x78, 0x74, 0xa6, 0x75, 0xeb, 0x02, 0x4c, 0xfd, 0x75, 0x28, 0x3e, 0x59, 0x34, 0xfa,
    0x26, 0x35, 0x16, 0xbf, 0x00, 0xf2, 0xe8, 0xb9, 0xbb, 0x60, 0x89, 0xb5, 0xaf, 0x08, 0x5e, 0x58,
    0x85, 0x79, 0x1b, 0x0e, 0xf9, 0xf7, 0xc9, 0x01, 0x9e, 0x8e, 0xc8, 0x8f, 0xef, 0xae, 0x8b, 0x34,
    0x7a, 0x8f, 0xd6, 0x1c, 0x71, 0x78, 0x28, 0xb8, 0xc0, 0xe4, 0x8f, 0x2e, 0xe3, 0x1b, 0xcd, 0xfa,
    0x1f, 0xe4, 0xef, 0x5e, 0xea, 0x3b, 0xda, 0x8b, 0x1d, 0xd3
};
#endif

PyTypeObject *init_QWebEngineProfileBuilder(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineProfileBuilder_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineProfileBuilder_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineProfileBuilder",
        "QWebEngineProfileBuilder*",
        &Sbk_QWebEngineProfileBuilder_spec,
        &Shiboken::callCppDestructor< ::QWebEngineProfileBuilder >,
        Sbk_QWebEngineProfileBuilder_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineProfileBuilder_TypeF(); // references _Sbk_QWebEngineProfileBuilder_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineProfileBuilder_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineProfileBuilder_SignatureBytes, QWebEngineProfileBuilder_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineProfileBuilder_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineProfileBuilder_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineProfileBuilder_PythonToCpp_QWebEngineProfileBuilder_PTR,
        is_QWebEngineProfileBuilder_PythonToCpp_QWebEngineProfileBuilder_PTR_Convertible,
        QWebEngineProfileBuilder_PTR_CppToPython_QWebEngineProfileBuilder);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfileBuilder");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfileBuilder*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineProfileBuilder&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineProfileBuilder).name());

    qRegisterMetaType< ::QWebEngineProfileBuilder *>();

    return pyType;
}
