// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineurlschemehandler_wrapper.h"

// Wrappers providing overrides
#include "qwebenginewebauthuxrequest_wrapper.h"

// Argument includes
#include <QtWebEngineCore/qwebengineurlrequestjob.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QWebEngineUrlSchemeHandlerWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QWebEngineUrlSchemeHandlerWrapper::QWebEngineUrlSchemeHandlerWrapper(::QObject * parent) : QWebEngineUrlSchemeHandler(parent)
{
}

void QWebEngineUrlSchemeHandlerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    QWebEngineWebAuthUxRequestWrapper::sbk_o_childEvent("QWebEngineUrlSchemeHandler", funcName, gil, pyOverride, event);
}

void QWebEngineUrlSchemeHandlerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    QWebEngineWebAuthUxRequestWrapper::sbk_o_connectNotify("QWebEngineUrlSchemeHandler", funcName, gil, pyOverride, signal);
}

void QWebEngineUrlSchemeHandlerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    QWebEngineWebAuthUxRequestWrapper::sbk_o_customEvent("QWebEngineUrlSchemeHandler", funcName, gil, pyOverride, event);
}

void QWebEngineUrlSchemeHandlerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    QWebEngineWebAuthUxRequestWrapper::sbk_o_connectNotify("QWebEngineUrlSchemeHandler", funcName, gil, pyOverride, signal);
}

bool QWebEngineUrlSchemeHandlerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return QWebEngineWebAuthUxRequestWrapper::sbk_o_event("QWebEngineUrlSchemeHandler", funcName, gil, pyOverride, event);
}

bool QWebEngineUrlSchemeHandlerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return QWebEngineWebAuthUxRequestWrapper::sbk_o_eventFilter("QWebEngineUrlSchemeHandler", funcName, gil, pyOverride, watched, event);
}

void QWebEngineUrlSchemeHandlerWrapper::requestStarted(::QWebEngineUrlRequestJob * arg__1)
{
    static const char *funcName = "requestStarted";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("QWebEngineUrlSchemeHandler.requestStarted");
        return;
    }
    sbk_o_requestStarted("QWebEngineUrlSchemeHandler", funcName, gil, pyOverride, arg__1);
}

void QWebEngineUrlSchemeHandlerWrapper::sbk_o_requestStarted(const char *ownerClassName, const char *funcName, Shiboken::GilState &gil, const Shiboken::AutoDecRef &pyOverride, ::QWebEngineUrlRequestJob * arg__1)
{
    SBK_UNUSED(ownerClassName)
    SBK_UNUSED(funcName)
    SBK_UNUSED(gil)
    SBK_UNUSED(pyOverride)
#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void QWebEngineUrlSchemeHandlerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, gil, funcName, &m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    QWebEngineWebAuthUxRequestWrapper::sbk_o_timerEvent("QWebEngineUrlSchemeHandler", funcName, gil, pyOverride, event);
}

const QMetaObject *QWebEngineUrlSchemeHandlerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QWebEngineUrlSchemeHandler::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QWebEngineUrlSchemeHandlerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QWebEngineUrlSchemeHandler::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QWebEngineUrlSchemeHandlerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QWebEngineUrlSchemeHandlerWrapper *>(this));
    return QWebEngineUrlSchemeHandler::qt_metacast(_clname);
}

QWebEngineUrlSchemeHandlerWrapper::~QWebEngineUrlSchemeHandlerWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineUrlSchemeHandler_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]);
    if (type == myType) {
        Shiboken::Errors::setInstantiateAbstractClass("QWebEngineUrlSchemeHandler");
        return -1;
    }

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineUrlSchemeHandler >()))
        return -1;

    QWebEngineUrlSchemeHandlerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QWebEngineUrlSchemeHandler", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineUrlSchemeHandler::QWebEngineUrlSchemeHandler(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QWebEngineUrlSchemeHandler(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QWebEngineUrlSchemeHandler(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))) {
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QWebEngineUrlSchemeHandler(QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QWebEngineUrlSchemeHandlerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QWebEngineUrlSchemeHandlerWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QWebEngineUrlSchemeHandler >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QWebEngineUrlSchemeHandlerFunc_requestStarted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineUrlSchemeHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWebEngineUrlSchemeHandler::requestStarted(QWebEngineUrlRequestJob*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlRequestJob_IDX]), (pyArg)))) {
        overloadId = 0; // requestStarted(QWebEngineUrlRequestJob*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "requestStarted", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWebEngineUrlRequestJob *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // requestStarted(QWebEngineUrlRequestJob*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("QWebEngineUrlSchemeHandler.requestStarted");
                return {};
            }
            cppSelf->requestStarted(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QWebEngineUrlSchemeHandler_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineUrlSchemeHandler_methods[] = {
    {"requestStarted", reinterpret_cast<PyCFunction>(Sbk_QWebEngineUrlSchemeHandlerFunc_requestStarted), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QWebEngineUrlSchemeHandler_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QWebEngineUrlSchemeHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QWebEngineUrlSchemeHandlerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QWebEngineUrlSchemeHandler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineUrlSchemeHandler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineUrlSchemeHandler_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineUrlSchemeHandler_TypeF(void)
{
    return _Sbk_QWebEngineUrlSchemeHandler_Type;
}

static PyType_Slot Sbk_QWebEngineUrlSchemeHandler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QWebEngineUrlSchemeHandler_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineUrlSchemeHandler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineUrlSchemeHandler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineUrlSchemeHandler_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineUrlSchemeHandler_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineUrlSchemeHandler_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineUrlSchemeHandler_slots
};

} //extern "C"

static void *Sbk_QWebEngineUrlSchemeHandler_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QWebEngineUrlSchemeHandler *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineUrlSchemeHandler_PythonToCpp_QWebEngineUrlSchemeHandler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineUrlSchemeHandler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineUrlSchemeHandler_PythonToCpp_QWebEngineUrlSchemeHandler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineUrlSchemeHandler_TypeF()))
        return QWebEngineUrlSchemeHandler_PythonToCpp_QWebEngineUrlSchemeHandler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineUrlSchemeHandler_PTR_CppToPython_QWebEngineUrlSchemeHandler(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QWebEngineUrlSchemeHandler *>(const_cast<void *>(cppIn)), Sbk_QWebEngineUrlSchemeHandler_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineUrlSchemeHandler_SignatureStrings[] = {
    "PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler(self,parent:PySide6.QtCore.QObject=nullptr)",
    "PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler.requestStarted(self,arg__1:PySide6.QtWebEngineCore.QWebEngineUrlRequestJob)",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineUrlSchemeHandler_SignatureByteSize = 123;
static constexpr uint8_t QWebEngineUrlSchemeHandler_SignatureBytes[123] = {
    0x78, 0xda, 0x0b, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x09, 0x4f, 0x4d, 0x72,
    0xcd, 0x4b, 0xcf, 0xcc, 0x4b, 0x75, 0xce, 0x2f, 0x4a, 0xd5, 0x0b, 0x84, 0x73, 0x43, 0x8b, 0x72,
    0x82, 0x93, 0x33, 0x52, 0x73, 0x53, 0x3d, 0x12, 0xf3, 0x52, 0x72, 0x52, 0x8b, 0x34, 0x8a, 0x53,
    0x73, 0xd2, 0x74, 0x0a, 0x12, 0x8b, 0x52, 0xf3, 0x4a, 0xac, 0x02, 0xe0, 0xda, 0x21, 0xba, 0xfc,
    0x93, 0xb2, 0x52, 0x93, 0x4b, 0x6c, 0xf3, 0x4a, 0x73, 0x72, 0x0a, 0x4a, 0x8a, 0x34, 0xb9, 0x02,
    0x48, 0x36, 0x5e, 0xaf, 0x28, 0xb5, 0xb0, 0x34, 0xb5, 0xb8, 0x24, 0xb8, 0x24, 0xb1, 0xa8, 0x24,
    0x35, 0x05, 0x62, 0x5b, 0x62, 0x51, 0x7a, 0x7c, 0xbc, 0xa1, 0x15, 0x51, 0xa6, 0x05, 0x41, 0xf4,
    0x7b, 0xe5, 0x27, 0x69, 0x72, 0x01, 0x00, 0x9b, 0x88, 0x51, 0xb4
};
#endif

PyTypeObject *init_QWebEngineUrlSchemeHandler(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineUrlSchemeHandler_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QWebEngineUrlSchemeHandler_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineUrlSchemeHandler",
        "QWebEngineUrlSchemeHandler*",
        &Sbk_QWebEngineUrlSchemeHandler_spec,
        &Shiboken::callCppDestructor< QWebEngineUrlSchemeHandler >,
        Sbk_QWebEngineUrlSchemeHandler_Type_bases.object(),
        0);
    auto *pyType = Sbk_QWebEngineUrlSchemeHandler_TypeF(); // references _Sbk_QWebEngineUrlSchemeHandler_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineUrlSchemeHandler_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineUrlSchemeHandler_SignatureBytes, QWebEngineUrlSchemeHandler_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineUrlSchemeHandler_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineUrlSchemeHandler_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineUrlSchemeHandler_PythonToCpp_QWebEngineUrlSchemeHandler_PTR,
        is_QWebEngineUrlSchemeHandler_PythonToCpp_QWebEngineUrlSchemeHandler_PTR_Convertible,
        QWebEngineUrlSchemeHandler_PTR_CppToPython_QWebEngineUrlSchemeHandler);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlSchemeHandler");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlSchemeHandler*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineUrlSchemeHandler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineUrlSchemeHandler).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QWebEngineUrlSchemeHandlerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QWebEngineUrlSchemeHandler_TypeF(), &Sbk_QWebEngineUrlSchemeHandler_typeDiscovery);

    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QWebEngineUrlSchemeHandler::staticMetaObject, sizeof(QWebEngineUrlSchemeHandlerWrapper));

    return pyType;
}
